@@ -43,8 +43,7 @@ module Specinfra
       end
 
       def method_missing(meth, val=nil)
-        key = meth.to_s
-        key.gsub!(/=$/, '')
+        key = meth.to_s.gsub(/=$/, '')
         ret = nil
         begin
           if ! val.nil?
